## Random Word Generation
This is a package to generate random english words

### Install
`pip install random-word-gen`

### Use
```
import random_word_gen as r
word = r.random_word() 
colour = r.random_colour()
```